@@ -37,6 +37,7 @@ from clusterondemand.utils import (
     is_writable_directory
 )
 from clusterondemandconfig import ConfigNamespace, config
+from clusterondemandconfig.configuration_validation import must_be_nonnegative
 
 from .decorators import retry
 
@@ -65,6 +66,7 @@ clusterssh_ns.add_parameter(
     advanced=True,
     default=30,
     help="Timeout for establishing an SSH connection with the cluster",
+    validation=must_be_nonnegative,
 )
 
 log = logging.getLogger("cluster-on-demand")
@@ -551,6 +553,10 @@ class SSHExecutor(object):
         if connect_timeout is None:
             connect_timeout = config.get("ssh_connect_timeout")
 
+        # if some command makes use of this class but forgets to import --ssh-connect-timeout,
+        # this will lead to unclear errors.
+        assert type(connect_timeout) is int and connect_timeout >= 0, "timeout must be positive integer"
+
         self._host = host
         self._user = user or "root"
         self._identity_files = identity_files
